"""Setup."""
import subprocess
from setuptools import find_packages, setup

# Install lambo using pip
subprocess.call(['pip', 'install', 'git+https://gitlab.clarin-pl.eu/syntactic-tools/lambo.git#egg=lambo'])

REQUIREMENTS = [
    'absl-py==0.9.0',
    'allennlp==1.3.0',
    'conllu==2.3.2',
    'dataclasses;python_version<"3.7"',
    'jsonnet==0.15.0',
    'filelock==3.0',
    'numpy==1.22.0;python_version>="3.8"',
    'numpy==1.21.6;python_version<"3.8"',
    'overrides==3.1.0',
    'requests==2.23.0',
    'sentencepiece==0.1.83;python_version<"3.8"',
    'sentencepiece==0.1.85;python_version>="3.8" and python_version<"3.9"',
    'sentencepiece==0.1.94;python_version>="3.9"',
    'scipy<1.6.0;python_version<"3.7"',  # SciPy 1.6.0 works for 3.7+
    'scipy==1.6.0;python_version>="3.7"',
    'spacy==2.3.2',
    'scikit-learn==0.23.2',
    'torch==1.7.1',
    'tqdm==4.43.0',
    'transformers==4.0.1',
    'urllib3==1.25.11',
    "lambo"
]

setup(
    name='combo',
    version='1.0.7',
    author='Mateusz Klimaszewski',
    author_email='M.Klimaszewski@ii.pw.edu.pl',
    install_requires=REQUIREMENTS,
    packages=find_packages(exclude=['tests']),
    license='GPL-3.0',
    url='https://gitlab.clarin-pl.eu/syntactic-tools/combo',
    keywords="nlp natural-language-processing dependency-parsing",
    setup_requires=['pytest-runner',
    		        'pytest-pylint',
                    'scikit-learn==0.23.2',
    		        'numpy==1.22.0;python_version>="3.8"',
                    'numpy==1.21.6;python_version<"3.8"',
    		        'scipy==1.6.0;python_version>="3.7"'],
    tests_require=['pytest', 'pylint'],
    python_requires='>=3.6',
    package_data={'combo': ['config.graph.template.jsonnet', 'config.template.jsonnet']},
    entry_points={'console_scripts': ['combo = combo.main:main']},
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Topic :: Scientific/Engineering :: Artificial Intelligence'
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ]
)
